#
# spec file for package gromox
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _libexecdir %_prefix/libexec

Name:           gromox
Version:        2.41
Release:        1.1
Summary:        Groupware server backend with RPC, IMAP,POP3, PHP-MAPI support
License:        AGPL-3.0-or-later AND GPL-2.0-only AND GPL-3.0-or-later
Group:          Productivity/Networking/Email/Servers
URL:            https://grommunio.com/
Source:         https://github.com/grommunio/gromox/releases/download/%name-%version/%name-%version.tar.zst
Source2:        https://github.com/grommunio/gromox/releases/download/%name-%version/%name-%version.tar.asc
Source8:        %name.keyring
BuildRequires:  fdupes
%if 0%{?suse_version} && 0%{?suse_version} < 1600
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc-c++
%endif
%if 0%{?suse_version}
BuildRequires:  libmysqlclient-devel >= 5.6
BuildRequires:  openldap2-devel
%else
BuildRequires:  mariadb-devel >= 5.6
BuildRequires:  openldap-devel
%endif
BuildRequires:  libtool >= 2
BuildRequires:  make
BuildRequires:  pam-devel
BuildRequires:  pkg-config
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150400
BuildRequires:  php8-devel
%else
BuildRequires:  php-devel >= 7
%endif
BuildRequires:  zstd
BuildRequires:  group(gromox)
BuildRequires:  pkgconfig(fmt) >= 8
BuildRequires:  pkgconfig(jsoncpp) >= 1.4.0
BuildRequires:  pkgconfig(krb5-gssapi)
BuildRequires:  pkgconfig(libHX) >= 4.19
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libesedb)
BuildRequires:  pkgconfig(libolecf)
BuildRequires:  pkgconfig(libpff)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxxhash)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(tinyxml2) >= 8
BuildRequires:  pkgconfig(wmime) >= 1
BuildRequires:  pkgconfig(zlib)
BuildRequires:  user(grommunio)
BuildRequires:  user(gromox)
%if 0%{?suse_version}
Requires:       glibc-locale-base
%endif
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150400
# Require php-cli/fpm (and modules) that have a chance of loading mapi.so
# which means same generation as the one we built with.
Requires:       php8-cli
Requires:       php8-fpm
Requires:       php8-mysql
Requires:       php8-posix
Requires:       php8-soap
%endif
%if 0%{?rhel} || 0%{?fedora_version}
Requires:       php-cli
Requires:       php-fpm
Requires:       php-mysqlnd
Requires:       php-posix
Requires:       php-soap
%endif
Requires:       w3m
Requires(pre):  user(grommunio)
Requires(pre):  user(gromox)
Requires(pre):  group(gromox)
Provides:       php-mapi-gromox = %version-%release
Conflicts:      grommunio-admin-api < 1.10.7
Recommends:     mapitags
%{?systemd_ordering}
%if !0%{?_pamdir:1}
%define _pamdir /%_lib/security
%endif

%description
Gromox is the central groupware server component of grommunio. It is
capable of serving as a replacement for Microsoft Exchange and
compatibles. Connectivity options include RPC/HTTP (Outlook
Anywhere), MAPI/HTTP, IMAP, POP3, an SMTP-speaking LDA, and a PHP
module with a Z-MAPI function subset.

Import is possible from PST/OST/MSG/CDFV2/TNEF, EML/ICAL/VCF, Kopano,
Zarafa, and via imapsync.

Gromox relies on other components to provide a sensibly complete mail
system, such as Postfix as a mail transfer agent, and grommunio-admin
for user management. A webmail client interface is available with
grommunio-web. The grommunio appliance ships these essentials and has a
ready-to-run installation of Gromox.

%prep
%autosetup -p1

%build
%configure \
%if 0%{?suse_version} && 0%{?suse_version} < 1600
	CC=gcc-12 CXX=g++-12 \
%endif
	%nil
%make_build V=1

%install
b="%buildroot"
%make_install
%if "%_pamdir" != "%_libdir/security"
# libtool gets confused if pamlibdir is not below prefix;
# as such we are not using `make install pamlibdir=...`
mkdir -pv "$b/%_pamdir"
mv "$b/%_libdir/security"/* "$b/%_pamdir/"
%endif
# done in system-user-gromox (which exists for ease of building for multiple distros)
rm -fv "%buildroot/%_sysusersdir/sysusers-gromox.conf"
for i in /var/lib/gromox /var/lib/gromox/domain \
    /var/lib/gromox/queue \
    /var/lib/gromox/queue/mess /var/lib/gromox/queue/save \
    /var/lib/gromox/queue/cache \
    /var/lib/gromox/queue/timer /var/lib/gromox/user \
    /var/log/gromox; do
	mkdir -p "$b/$i"
done

find "$b" -type f -name "*.la" -delete
rm -fv "$b/%_libdir"/*.so

mkdir -p "$b/%_sysconfdir/%name" "$b/%_datadir/%name"
%if 0%{?suse_version} >= 1550 || 0%{?sle_version} >= 150400
mkdir -p "$b/etc/php8/fpm/php-fpm.d"
cp -a "$b/usr/share/gromox/fpm-gromox.conf.sample" "$b/etc/php8/fpm/php-fpm.d/gromox.conf"
%endif
%if 0%{?sle_version} && 0%{?sle_version} < 150400
mkdir -p "$b/etc/php7/fpm/php-fpm.d"
cp -a "$b/usr/share/gromox/fpm-gromox.conf.sample" "$b/etc/php7/fpm/php-fpm.d/gromox.conf"
%endif
%if 0%{?rhel} || 0%{?fedora_version}
mkdir -p "$b/etc/php-fpm.d"
cp -a "$b/usr/share/gromox/fpm-gromox.conf.sample" "$b/etc/php-fpm.d/gromox.conf"
%endif
perl -i -lpe 's{Type=simple}{Type=simple\nRestart=on-failure}' "$b/%_unitdir"/*.service
%fdupes %buildroot/%_prefix

%global services gromox-delivery.service gromox-delivery-queue.service gromox-event.service gromox-http.service gromox-imap.service gromox-midb.service gromox-pop3.service gromox-snapshot.service gromox-snapshot.timer gromox-timer.service gromox-zcore.service

%if 0%{?service_add_pre:1}
%pre
# User addition done a priori by system-user-gromox(!)
%service_add_pre %services
%endif

%post
/sbin/ldconfig
%tmpfiles_create tmpfiles-gromox.conf
%if 0%{?service_add_post:1}
%service_add_post %services
%else
%systemd_post %services
%endif
if ! test -x /usr/bin/systemctl; then
	exit 0
fi
# saslauthd re-opens pam_gromox.so everytime, however
# libgromox_common.so stays resident because of STB_UNIQUE symbols,
# therefore saslauthd can run into the problem that a new version of
# the pam module will be combined with a too old version of gromox
# libs. No good solution in sight..
/usr/bin/systemctl try-restart grommunio-chat.service php-fpm.service saslauthd.service 2>/dev/null || :
# Delete old service links
if /usr/bin/systemctl is-enabled gromox-exch.target >/dev/null 2>/dev/null; then
	echo Migrating gromox-exch.target
	/usr/bin/systemctl enable gromox-http.service gromox-midb.service gromox-zcore.service || :
	/usr/bin/systemctl disable gromox-exch.target || :
fi
if /usr/bin/systemctl is-enabled gromox-mra.target >/dev/null 2>/dev/null; then
	echo Migrating gromox-mra.target
	/usr/bin/systemctl enable gromox-imap.service gromox-pop3.service || :
	/usr/bin/systemctl disable gromox-mra.target || :
fi
if /usr/bin/systemctl is-enabled gromox-mta.target >/dev/null 2>/dev/null; then
	echo Migrating gromox-mta.target
	/usr/bin/systemctl enable gromox-delivery.service gromox-delivery-queue.service || :
	/usr/bin/systemctl disable gromox-mta.target || :
fi
if /usr/bin/systemctl is-enabled gromox-sa.target >/dev/null 2>/dev/null; then
	echo Migrating gromox-sa.target
	/usr/bin/systemctl enable gromox-event.service gromox-timer.service || :
	/usr/bin/systemctl disable gromox-sa.target || :
fi

%preun
%if 0%{?service_del_preun:1}
%service_del_preun %services
%else
%systemd_preun %services
%endif

%postun
%if 0%{?service_del_postun:1}
%service_del_postun %services
%else
%systemd_postun_with_restart %services
%endif
/sbin/ldconfig

%files
%_sysconfdir/php*
# "grommunio" permission is exercised by grommunio-admin-api.
# pam.cfg needs to be accessible by arbitrary programs (hence we need at least 0751).
%attr(0755,grommunio,gromoxcf) %dir %_sysconfdir/%name/
%_sbindir/gromox-*
%_libdir/*.so.*
%_libdir/%name/
%_libdir/php*/
%_libexecdir/%name/
%_pamdir/
%_datadir/%name/
%_mandir/man*/*.[0-9]*
%_tmpfilesdir/*.conf
%_unitdir/*
%attr(0770,gromox,gromox) /var/lib/gromox/
%attr(0770,gromox,gromox) /var/log/gromox/
%if 0%{?suse_version} >= 1500 && 0%{?suse_version} < 1550
%dir %_libexecdir
%endif
%license LICENSE.txt
%doc doc/changelog.rst

%changelog
* Fri Feb  7 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.41
  * ldap_adaptor: plug two memory leaks
  * exmdb: plug a memory leak related to subscription destruction
  * oxcical: do process TRIGGER duration value type for reminders
  * midb: resolve flakey update of flagged/replied/forwarded status
  * midb: when a MAPI message has changed and requires a new
    IMAPUID, convey the expunge of the old IMAPUID much sooner to
    IMAP clients
  * pop3: resolve a NULL deref/crash during RETR command
  * imap: restore SEARCH command looking at right portion of a
    QP-encoded message
  * mkprivate: new message stores now have `frightsVisible` set
    on the calendar folder
* Tue Jan 28 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.40
  * zcore: avoid unwrapping Content-Transfer-Encoding twice for
    clearsigned S/MIME
  * ews: calculate timezone offsets for local time only
  * imap, pop3: multi-server capability, replacing direct disk
    I/O by network RPCs to the exmdb storage backend
* Tue Jan 21 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.39
  * midb: synchronize "Answered", "Forwarded" and "Flagged" flags
    between MAPI and midb
  * midb: pass message flag modification notifications
    (answered/forwarded/flagged/read/etc.) to imapd
  * mbop: new foreach.* command group which replaces for-all-users
* Sat Dec  7 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.38
  * oxcical: ignore zero-length PidLidTimeZoneStruct on export
    rather than failing the operation
  * freebusy: process events with recurrence patterns > 510 bytes
  * mbop-get-freeubsy: respect the absence of start_time,end_time
    (-a/-b) parameters
  * mapi_lib: support TNEF export of messages without
    PR_INTERNET_CPID
  * email_lib: no longer reject import of time-based recurrent
    series (`RRULE` line with `UNTIL` specifier) with a single
    occurrence
  * midb: deal with folder changes that occurr during times when
    midb is not running
  * exm2eml: add TNEF file export support
  * imap: reject creating extant folder
  * midb: change M-COPY from a read-write cycle to server-side
    copy, thereby preserving mail headers from now on
  * midb/imapd: folder names are now treated case-sensitive, just
    like MAPI did it already
* Wed Nov 20 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.37
  * exmdb: fix garbage being returned to clients when reading v1z
    files from cid/
  * exmdb: stop an SQL error from appearing when `gromox-mbop
    recalc-sizes` is used on an empty store
  * oxcical: evaluate all, instead of just two, STANDARD/DAYLIGHT
    tzprops for determining the relevant DST timezone
  * ews: fix time elements, e.g. in OOF settings, always having
    value 1970-01-01
  * email_lib: on vCard ingestion, treat ORG lines as the
    structured field that they are specified as, rather than as
    one text value
  * exmdb_local: autovivify new named properties on delivery,
    fixing log message ``D-1220`` when ingesting a vCard message
    into an empty store via SMTP/LMTP
  * dbop_sqlite: avoid use of the ``UNIXEPOCH`` function since it
    is not available in AlmaLinux 9
  * lib: add missing chown call on newly-created logfiles to
    account for subsequent privilege separation
  * dscli: evaluate not just one AutoDiscover URL but multiple as
    the specifation asks for
  * mbop: stop printing the help text multiple times when the
    "for-all-users" subcommand was used but options were rejected
  * gromox-mbsize: new debug utility for mailbox size analysis
  * gromox-tnef2mt: add support for importing standalone TNEF files
* Wed Nov  6 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.36
  * ews: fix an ABA locking problem when EWS unsubscribe actions
    were processed
  * genimport: fix a data juggling issue that led to mt2exm
    printing ``proptag … from input stream has no named property
    info``
  * mbck: do not attempt to repair allocated_eids if repair mode
    was not selected, fixing mbck printing ``sqlite3_prep(INSERT
    INTO allocated_eids) ... inside a readonly TXN``.
  * exmdb: fix an issue where creating new embedded messages
    could lead to ``sqlite3_exec(… INSERT INTO messages ...
    VALUES (65536, …): UNIQUE constraint failed: messages.message_id (19)``
  * mkprivate et al: fix an issue where force-overwriting
    databases would print "database is locked"
  * mbop: new commands "ping", "for-all-users", "echo-username"
  * exmdb: faster process shutdown through parallelized closing
    of sqlite files
  * exmdb: better location diagnostics for RO-RO transactions,
    for RW-in-RO, and ROLLBACK issues
  * exmdb: deactivate implicit integrity check when upgrading a
    mailbox's database schema, it takes too much time
    (Integrity checks can still be done offline with ``mkprivate
  - U --integ``)
* Tue Oct 15 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.35
  * alias_resolve: resolve nullptr deref crash
  * ews: resolve nullptr deref crash
  * mapi_lib: fix out-of-bounds access in PROBLEM_ARRAY::transform
  * mapi_lib: rop_util_get_gc_value used the wrong mask, which
    caused "Change commit failed because the object was changed
    separately"
  * exmdb: let PR_ACCESS include permissions from all group
    memberships
* Tue Oct  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.34
  * php_mapi: cure crash occurring with mapi_getidsfromnames
  * midb: resolve "inside a readonly TXN" warnings during message
    deletion
  * exmdb: emit notifications only after SQL transactions are
    complete
  * imap: resolve unstable EXPUNGE observability
* Tue Oct  1 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.33
  * oxcmail: Implement MIME fragment joining for the construction
    of the contents of PR_HTML.
  * dscli: add --ac option to test Mail Autoconfig (what
    Thunderbird uses in leu of AutoDiscover)
  * http: credential caching for HTTP Basic (config directive
    ``http_basic_auth_cred_caching``, defaulting to 60s)
  * oxcical: revert commit which evaluates different MAPI
    timezone properties to generate DTSTART/DTEND's TZID value
* Wed Sep  4 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.32
  * mysql_adaptor: re-speedup queries that came to ran without an
    index
  * mbop: make the "clear-profile" operation do clear g-web
    settings again
  * zcore: workaround potential hang during shutdown
  * emsmdb, zcore: allow "Empty Folder" operations in public stores
  * exmdb: increased verbosity during shutdown phase so it does
    not appear like a hang
* Wed Aug 14 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.31
  * freebusy: get_freebusy erroneously underreported occurrences
    for yearly occurrences
  * freebusy: the get_freebusy routine erroneously landed in an
    infinite loop if a yearly-recurring February 29 appointment
    was originally created in a year not divisible by 12.
  * oxcmail: take /etc/mime.types under consideration when adding
    extensions to attachments
  * oxcmail: priorities for MIME parts have been rectified for
    multipart/alternative and non-alternative containers; the
    conversion routine is no longer making picks across multiple
    container siblings.
* Fri Jun 21 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.30
  * oxcical: emit VTIMEZONE for events without
    PidLidAppointmentTimeZoneDefinitionStartDisplay
  * gromox-mbop: new subcommand ``set-locale`` to change store
    language
  * exmdb: add more SQLite transactions and make concurrent read
    access for stores possible
  * ruleproc: initial autoprocessing for meeting requests
  * conflict detection, response sending for conflicts,
    automatic addition to calendar
  * needs to be enabled with gromox.cfg:``lda_mrautoproc``=yes
  * imap, pop3, delivery-queue: HAProxy protocol support
    (send-proxy-v2)
  * zcore: show private distribution lists the grommunio-web
    address book
* Mon Jun  3 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.29
  * dnsbl_filter: support DNSBL servers that do not emit TXT records
  * email_lib: cure IMAP Structure Descriptions indicating a mail
    size 2 bytes larger than it is
  * imap: cope with truncated EML files
  * exmdb: delete leftover stray ROLLBACK statement
  * ews: cure null dereference in tInternetMessageHeader::parse
  * ews: use vmime parser to break down IMHs and reset an Apple
    workaround for "From" lines
* Thu May  2 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.28
  * imap: cure client session hang when midb failed to add
    a mail during 64K-append
  * mysql_adaptor: allow Unicode in alternate usernames (altnames)
  * Populate PR_DELETED_ON property for softdeleted items
  * exmdb: ``exmdb_rpc_debug`` will now emit execution time for
    EXRPCs
  * zcore: ``zrpc_debug`` logging now includes the session GUID
    to help correlate which ZRPCs are executed by which user
  * imap, pop3: print client IP address for lines from
    ``imap_cmd_debug``/``pop3_cmd_debug``
* Sun Apr  7 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.27
  * email_lib: avoid splitting UTF-8 code units across lines
  * imap: avoid emitting NIL for body-fld-lines
  * php_mapi: expose default+anonymous ACEs to PHP programs
  * zcore: expose new PR_EC_ENABLED_FEATURES_L property
  * ews: implement updating folder permissions
  * eml2mt: emit a hint if an Outlook .msg file is erroneously
    passed to eml2mt
* Mon Mar 11 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.26
  * exmdb: Fix restriction mismatching on ``PR_PARENT_SVREID`` &
    ``PR_PARENT_ENTRYID``, which had caused reminders to go off
    even after appointments were moved to the wastebasket.
  * exmdb_local: rectify wrong/empty ``From:`` lines in bounce
    messages
  * ews: fix segfault when loading public folder item
  * zcore: repaired thumbnail retrieval, which used the wrong
    directory
  * mbop: add subcommands for manipulating websettings_persistent
  * zcore: store websettings_persistent directly in the store
    rather than the zcore shadow store object (automatic
    migration is in place)
  * kdb2mt: avoid importing ``PR_EC_WEBAPP_PERSISTENT_SETTINGS_JSON``
    property
* Thu Feb 29 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.25
  * mt2exm: the -B option can be used with all folder names
  * mbop: new commands ``get-photo``, ``set-photo``,
    ``get-websettings``, ``set-websettings``
  * oxcmail: export no longer generates a MIME epilogue, which
    should workaround Outlook's broken S/MIME validator which
    fails to include epilogues in the signature verification.
  * mkpublic: newly created public stores lacked a
    ``replguidmap`` table
  * exmdb: repair initialization of PR_ATTACH_NUM when instances
    are opened
  * oxcmail: strip leftover right angled bracket from Content-ID
    on oxcmail_import
* Sat Feb 10 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.24
  * email_lib: the last byte of a MIME part was erroneously deleted
  * emsmdb: repair garbage memory read when creating a stream on
    a PT_STRING8 property
  * ews: repair a potential lack of results with the ResolveNames
    operation when searching by email address
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.23
  * oxcmail: do not ignore IDN addresses when reading headers
  * oxcmail: resolve a case with trashed body bytes when a line
    began with dot
  * exmdb: add config directive ``exmdb_contention_reject_time``
    for configuring contention timeout
  * exmdb: have DB_ITEM instances track which function holds them,
    and report this upon reaching contention timeouts
  * new command: gromox-exm2mt
* Mon Jan 29 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.22
  * exmdb_client: discard connections when EOF is detected
  * mda: resolve three cases of garbage bytes getting added to
    messages
  * oxcmail: drop unintended doublequotes around RFC 2047-style
    =?..?= encoded-words
  * oxcical: support emission of iCalendar VFREEBUSY objects
  * nsp,ab: support name resolution of IDN addresses
  * twostep_ruleproc: support Outlook-style public folder entryids
    in Move/Copy rules (as opposed to GWeb-style entryids)
* Mon Jan  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.21
  * Support for outgoing message submission via postdrop
  * gromox-snapshot: Support snapshots on XFS
  * zcore: log REMOTE_ADDR on authentication failure for fail2ban
  * exmdb: add ICS request dumper
  * lib: guard against an integer overflow when inserting last
    element in range_set
  * imap: do not flag zero-length usernames/passwords as a syntax
    error
* Fri Dec 15 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.20
  * oxdisco: allow autodiscover for room/equipment stores
  * oxcical: allday events are now emitted (pursuant to the
    ``oxcical_allday_ymd`` config directive) as "floating time"
    per the OXCICAL spec recommendations
  * oxcical: resolve integer underflow that botched weekorder
    computation in weekly-recurring events
  * oxcical: resolve out-of-bounds access during generation of
    iCal RDATE lines * ews: avoid a heap-use-after-free during
    freebusy retrieval
  * zcore: zs_getuserfreebusy had failed to resolve usernames and
    display freebusy status in the scheduling matrix view
  * ldap_adaptor: resolve data race with double-free when
    per-organization LDAP settings were used
* Mon Dec  4 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.19
  * `gromox-mbop emptyfld` now recognizes a `-t` option to limit
    deletion to messages of certain age.
  * `gromox-mbop emptyfld` now recognizes a `--nuke-folders` option
  * gromox-eml2mt now recognizes a `--mbox` option to support
    RFC4155 Unix mboxes
  * exmdb: search pacing is now time-based, which should give more
    predictable interactivity during background searches
  * emsmdb: do not treat the absence of the
    PR_LAST_MODIFICATION_TIME message property during ICS downloads
    as an error any longer
  * exmdb: send "object created" notifications as search folders
    re-populate
  * oxcmail: ignore zero-length From fields, which should help
    sending from Windows Mail
  * Thunderbird/IMAP now picks up deletion events done by other
    clients
* Mon Nov 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.18
  * exmdb: synthesized PR_RTF_COMPRESSED properties (in relation to
    the "dbg_synthesize_content" config directive) had an
    incomplete header
  * oxcmail: repair inadvertent propid/proptag swap causing TNEF
    export to fail
  * mbop/purge-softdelete: make pathspec `SENT/2022` actually work
  * imap: messages delete events from OL/g-web now make it to IMAP
    clients
  * midb: propagate folder change events; IMAP clients now
    recognize when a message was deleted in g-web/Outlook
  * http: RFC 7617 support for the Basic authentication header line
  * nsp: allow connections from Windows with UTF-8 locale
  * midb: removal of seqid renumbering, which speeds up
    IMAP SELECT/LIST/FETCH commands.
  * authmgr: PAM is now offered as an authentication backend
* Sat Nov 11 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.17
  * Enhancements:
  * http: Windows SSO support via HTTP Negotiate authentication
  * daemons: support for alternate login names
    (this allows for assigning shorter usernames for grommunio-web)
  * exmdb: augment create_folder and movecopy_folder RPCs with a
    32-bit error code, which allows g-web to better detect folders
    with duplicate names
  * ews: implement Subscribe, Unsubscribe, GetEvents, GetUserPhoto
  * mbop: add subcommand `clear-rwz` to clear out RuleOrganizer
    FAI messages
- Delete 0001-build-resolve-i586-compile-error.patch (merged)
* Sun Oct 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.16
  * Enhancements:
  * Define the "suspended" user state for grommunio-admin-api.
    (think of it as a "non-receiving shared mailbox").
  * emsmdb, zcore: the ``emsmdb_max_cxh_per_user``,
    ``emsmdb_max_obh_per_session`` and
    ``zcore_max_obh_per_session`` config directives can now be
    set to 0 for unlimited.
  * Fixes:
  * oxvcard: export to .vcf now positions the VERSION property in
    accordance with the vCard 4.0 specification.
  * oxcmail: cease gratuitous RTF conversion of calendar items.
* Wed Oct 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.15
  * imap: do not emit continuation request on LITERAL+ (now also
    for large literals >64K)
  * exmdb: explicitly rollback SQLite transactions when the commit
    operation failed
  * delivery: support for plus-addresses/recipient delimiters,
    e.g. <user+extension@example.com>
  * mbop: new subcommand ``recalc-size`` to recalculate store size
* Wed Oct  4 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.14
  * alias_resolve: support for nested mlist expansion
  * alias_resolve: support for Global Contact Objects
  * delivery: SIGHUP triggers a reload of (more) plugins now
  * gromox-mbop: add emptyfld options -a, -M
  * oxdisco, oab: avoid emitting extraneous NUL byte at end of
    XML document
  * imap: do not emit continuation request on LITERAL+
* Sat Sep 23 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.13
  * emsmdb: eliminiate duplicate message appearing when copying
    to a private non-default / shared store
  * EWS: support the {Create,Delete,Move,Copy,Update,Empty}Folder
    operation(s)
  * EWS: support the {Copy,Move}Item operation(s)
* Mon Sep  4 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.12
  * ews: support CreateItem, DeleteItem, SendItem requests
  * oxm2mt: support multi-valued properties
  * kdb2mt: do not abort when --src-mbox is used
  * exmdb_provider: opening the detail view of Personal Addressbook
    entries now works in Outlook, as does selecting them as message
    recipients
  * zcore: fix a flaw in permissions dialog that caused the
    delegates to be able to see the private items of the delegator
* Mon Aug 21 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.11
  * exmdb: attachment storage with hash-based filenames
  * exmdb_local: persistent (on-disk) last-autoreply time tracking
  * imap: allow large literals with APPEND
  * imap: add RFC 7888 support
  * oxdisco: allow AutoDiscover information retrieval from
    secondary mailboxes even if the scndstore_hints table does not
    have an entry.
  * emsmdb: "Mark all as read" in OL (Online mode) now works
* Thu Jun 15 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.10
  * DNSBL filtering mechanism, cf. man dnsbl_filter
  * Address book name resolution now evaluates alias addresses
  * pff2mt: speedup operation by 70%%+
  * emsmdb: strike limits (raise to infinity) for session
    handles, user handles and notify handles, and raise limit for
    ems_max_pending_sesnotif to 1K
  * emsmdb: new configuration directives ems_max_active_notifh,
    ems_max_active_sessions, ems_max_active_users,
    ems_max_pending_sesnotif
  * mbop: new subcommands clear-photo, clear-profile,
    purge-softdelete, purge-datafiles
* Wed May 10 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.9
  * emsmdb: support forwarding meeting requests from organizers
    that are not local to the installation
  * imap: broadcast changes to mailbox from EXPUNGE commands
  * oxcical: add TZID for allday events
  * imap: add and populate a per-context seqid list
  * midb: unbreak search matching based on dates and sizes
  * emsmdb: avoid hitting an assertion when sort-reloading a
    table of a deleted folder
- Delete 0001-dbop_mysql-remove-extraneous-DEFAULT-keyword-in-clas.patch
* Sat Apr 15 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.8
  * exmdb_provider: repair a 4-byte cutoff when reading PR_BODY,
    PR_TRANSPORT_MESSAGE_HEADERS if they are compressed on disk
  * nsp: fix janky addressbook navigation when the GAL has hidden
    entries
  * The "Hide from addresbook" functionality has gained another
    bit, so that name resolution ("Check names" button in
    OL/g-web) is no longer tied to visibility in the GAL.
  * Support for non-default stores in the IMAP and POP3 protocols;
    use "actualusername!sharedmbox" as the username for login.
- Add 0001-dbop_mysql-remove-extraneous-DEFAULT-keyword-in-clas.patch
* Fri Mar 24 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.7
  * exmdb_provider: default to mbox_contention_reject=0
  * zcore: make mapi_message_imtoinet operate on message instances,
    not messages
  * oxcmail: do not fail exporting DSNs with unresolvable addresses
  * oxcical: do not fail exporting calendar objects with
    unresolvable addresses
- Delete 0001-build-resolve-compile-error-with-gcc-13.patch,
  0001-snapshot-safer-parsing-of-snapshot.cfg.patch (merged)
* Mon Mar 20 2023 Jan Engelhardt <jengelh@inai.de>
- Add 0001-build-resolve-compile-error-with-gcc-13.patch
* Mon Mar 13 2023 Jan Engelhardt <jengelh@inai.de>
- Add 0001-snapshot-safer-parsing-of-snapshot.cfg.patch
  [boo#1209051]
- Updated directory permissions
* Thu Mar  9 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6
  * exmdb_provider: filter duplicate propids when they occur in
    the mailbox, resolving a failure to export (broken)
    recipients to MSG, and resolving _one_ instance of OL sync
    error 80070057.
  * oxvcard: PidLidBusinessCardDisplayDefinition named property
    was not assigned the right namespace (PSETID_ADDRESS)
  * oxcmail: do not abort export routine if SMIME message is
    lacking an SMIME body (just treat it as empty instead)
  * oxcical: do not abort export routine if IPM.*.Resp.* has no
    attendee
  * exmdb_local: perform online lookup of named properties,
    resolving vcarduid being erroneously assigned propid 0
* Sun Mar  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.5
  * authmgr: Alternate username support
  * Repair a null deref during HTML-to-text conversion
  * Synchronization of embedded messages now works
  * Saving a draft in grommunio-web would erroneously strip the
    subject prefix
  * EWS: Detailed FreeBusy requests did not return detailed info
* Sun Feb 26 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.4
  * mbop: emptyfld/delmsg support folder names now
  * dscli: added an --eas option
  * oxdisco: support autodiscover.json requests
* Fri Feb  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.3
  * pff2mt: support non-Unicode PFF files
  * ldap_adaptor: read ldap_start_tls, ldap_mail_attr from
    orgparam table
  * Support Emojis in HTML-to-RTF conversion code
  * exmdb_provider: implement message store softdelete count
    properties
  * dbop_sqlite: guard schema upgrades with transaction
  * Do not fail entire HTML-to-RTF conversion or calls like
    getpropvals(PR_RTF_COMPRESSED) when encountering garbage
    bytes
  * exmdb_provider: have folder message count properties respect
    softdelete
  * zcore: mapi_copyto had inverted meaning of MAPI_NOREPLACE
* Mon Jan 16 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.2
  * exmdb_provider: repair SQL logic errors showing up when a
    folder's contents are requested in Conversation mode
  * exmdb_provider: only delete links, not messages, from search
    folders
  * tools: add --integrity option for mkprivate, mkpublic, mkmidb
* Thu Jan 12 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.1
  * exmdb_provider: support for private store message and folder
    softdelete (and thus the Recover Deleted Items feature in OL)
  * mapi_lib: parse "Received" headers into
    PR_MESSAGE_DELIVERY_TIME for the sake of EML imports
  * emsmdb: work around OL crash with Recover Deleted Items dialog
  * emsmdb: rework interpretation of PR_SENT_REPRESENTING on
    IPM.Schedule objects (relates to the organizer of a meeting
    when such meeting is forwarded)
* Sun Dec 18 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.37
  * exmdb_provider: on-disk content file compression, controllable
    using the exmdb_file_compression config directive (affects only
    new files)
  * exmdb_provider: support evaluation of inbox rules that have
    RES_CONTENT restrictions with PT_BINARY properties
  * kdb2mt: full user resolution and PR_*_ADDRTYPE resolution with
    new option set --mbox-name/--user-map
  * zcore: Addressed "exmdb_client: reached maximum
    connections ..." warnings.
  * Selecting addresses from the "From" dropdown in OL's
    compose mail dialog works now.
* Fri Nov 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.35
  * kdb2mt: add option for mapping ACL identities using a text file
  * tools: add kdb-uidextract and kdb-uidextract-limited scripts to
    facilitate ACL conversion
  * Per-organization LDAP server support
  * User accounts can now be hidden from the GAL and other
    address lists
  * The gromox-dscli command-line utility now performs DNS SRV
    lookups.
  * exmdb_provider: mlists that were granted the StoreOwner
    permission bit through an ACL now propagate it to the
    individuals in the mlist.
  * emsmdb: On outgoing mails, the Return-Receipt-To (Read
    Receipt Request) header was malformed. On the incoming side,
    this would then be translated back to invalid@invalid.
* Tue Aug 30 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.31
  * kdb2mt: add a size column to the disambiguation table
  * exmdb_provider: added the "exmdb_search_yield" and
    "exmdb_search_nice" config directives
  * exmdb_provider: add a vacuum RPC (and expose via
    gromox-mbop(8gx))
  * emsmdb: implement cached mode cross-store move support
* Mon Jul 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.28
  * freebusy: do not publicize private recurrence exceptions
  * Delayed Sending had left messages in Outbox
  * emsmdb: the contact folder list erroneously rejected sort
    requests that grouped and sorted by the same column
* Sun Jun 12 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.25
  * exmdb_provider: repair PR_MEMBER_NAME transition (ACL table
    contents)
  * zcore: fix randomly occurring set_permission failures
  * autodiscover: resolve & in displaynames being misrepresented
  * autodiscover: force-remove single quotes from ini values
  * imap: improved the tokenization for unusual values found in
    the From/To/Reply-To etc. headers
  * imap: stop emitting excess parenthesis pairs for RFC822 field
    values during FETCH
  * imap: stop offering the STARTTLS capability keyword when the
    STARTTLS command can, at the same time, not be issued anyway
  * imap: IMAP commands emitted to the log (under imap_cmd_debug)
    were truncated sometimes
  * midb: resolve potential crash when the IMAP SEARCH command
    is used
* Wed Jun  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.24
  * exmdb_provider: lifted the folder limit from 10k to 28 billion
  * oxcmail: cease excessive base64 encoding.
  * Messages are now preferably encoded as quoted-printable
    during conversion to Internet Mail format. This might help
    with spam classification.
* Thu May 12 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.22
  * service_loader: resolve crash when first module is unloadable
  * eml2mt, exm2eml: rectify wrong serivce plugin search path
  * eml2mt: add iCalendar and vCard file import
  * kdb2mt: skip IPM.MessageManager FAI messages (cause Outlook
    to sometimes refuse opening a folder)
  * The /usr/libexec/gromox/autodiscover command has been renamed
    to just gromox-dscli.
* Sat Apr 30 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.20
  * Resolve a use-after-free in gromox-eml2mt
  * oxcmail: conversion of Reply-To MAPI field to Internet Mail
    had only used the last ONEOFF-type recipient, now it uses all
    ONEOFF recipients.
  * oxcmail: set IPM.Note.SMIME.MultipartSigned only for incoming
    S/MIME mails, not for OpenPGP mails.
  * autodiscover: Change the way autodiscover.ini is parsed. This
    allows a few more non-alphanumeric characters in the MariaDB
    password. ';' is still unusable.
  * exmdb_provider: Evaluate restrictions against absent values
    differently; this makes messages without a sensitivity tag
    and which are located in a non-default store visible in
    Outlook again.
* Sat Apr 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.19
  * kdb2mt: added the --with-acl option for partial conversion of ACLs
  * pff2mt: added the --only-obj option to extract a specific object
  * mt2exm: added the -B option for the placement of unanchored messages
  * eml2mt: new utility to import mails from files
  * exmdb_provider: new config directive "exmdb_schema_upgrades"
  * midb: new config directive "midb_schema_upgrades"
  * mkprivate, mkpublic and mkmidb now recognize the -U option to
    upgrade SQLite database schemas
  * mbop: new utility
  * rebuild: added progress indicator
  * zcore: new config directive "zcore_max_obh_per_session"
  * emsmdb: new config directives "emsmdb_max_obh_per_session",
    "emsmdb_max_cxh_per_user" to allow higher resource use when a
    lot of stores are used by an Outlook profile (warning
    W-1580).
* Fri Feb 11 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.16
  * zcore: allow setting Out Of Office status of other mailboxes
  * zcore: enhance mapi_getmsgstoretable to show all stores with
    access permissions
  * kdb2mt, pff2mt: add --with-hidden/--without-hidden
* Tue Jan 18 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.13
  * mt2exm: perform named property translation on folder
    properties, message recipient properties and attachment
    properties.
  * pff2mt: support reading multi-value variable-length property
    types, and obscure single-value types.
  * kdb2mt: analyze Receive Folder Table and map inbox to inbox
    when ``-s`` is used.
  * pam_gromox: Additional service mode checks. One can now use
    e.g. auth required pam_gromox.so service=chat in
    /etc/pam.d/xyz to test for the CHAT privilege bit.
* Tue Dec  7 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.10
  * exmdb_provider: cease adding a broken recipient when deleting
    last recipient
  * exmdb_provider: synthesize mandatory recipient properties
    essential for MSMAPI (the source of incomplete recipients is
    from imported KGWC databases)
  * emsmdb: work around Outlook not displaying any body in Cached
    Mode when there is no HTML body
  * mapi_lib: avoid making underscores in subjects when there are
    umlauts
* Fri Oct  8 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4
  * The event(8gx) and timer(8gx) daemons now run unprivileged.
  * gromox-pff2mt now skips over unrecognizable MAPI properties
    rather than exiting.
  * gromox-mt2exm now supports storing to public mailboxes.
* Wed Sep  1 2021 Jan Engelhardt <jengelh@inai.de>
- Initial entry for build.opensuse.org (gromox-1.1.43.566b624e)
